<?php

/**
 * @file
 * buddylist_ui.admin include file
 * 
 * contains functions for admin area
 */

/**
 * Generates overview of relationtypes
 */
function buddylist_ui_admin_overview() {
  $form = array();
  
  //active relationtypes
  $form['active'] = array('#value' => '<h2>'. t('Active relationtypes'). '</h2>');
  $form['active_table'] = buddylist_ui_admin_get_rtypes(1);
  
  //inactive relationtypes
  $form['inactive'] = array('#value' => '<h2>'. t('Inactive relationtypes'). '</h2>');
  $form['inactive_table'] = buddylist_ui_admin_get_rtypes(0);
  
  return $form;
}

/**
 * Generates table with active/inactive relationtypes and operation links
 */
function buddylist_ui_admin_get_rtypes($active_state) {
  // load all types
  $rtypes = buddylist_api_rtypes_load();
  $final_types = array();
  
  foreach($rtypes as $rtype) {
    // only add to table if the state matches
    if ($rtype->active == $active_state) {
      $path = 'admin/buddylist/rtypes/'. $rtype->rtid;
      $id = $rtype->rtid;     
      
      $ops = array();  
      $ops[] = l(t('edit'), $path .'/edit');
      $ops[] = l(t('delete'), $path .'/delete');
      
      $final_types[$id] = (array)$rtype;
      $final_types[$id]['oneway'] = ($final_types[$id]['oneway'] == 1) ? t('Yes') : t('No'); 
      $final_types[$id]['backrelation'] = ($final_types[$id]['backrelation'] == 1) ? t('Yes') : t('No');    
      $final_types[$id][] = implode(' ', $ops);
      
      // do not show if its active
      unset($final_types[$id]['active']); 
    }
  }
  
  // no relationtypes found
  if (!count($final_types)) {
    return array('#value' => '<p>'. t('None') .'</p>');
  }
 
  $header = array(t('Relation ID'), t('Machine Readable Name'), t('Name'), t('Oneway'), t('Free Backrelation'), t('Operations'));
  return array('#value' => theme('table', $header, $final_types));
}

/**
 * Returns the form for editing/adding a rtype
 */
function buddylist_ui_admin_form_edit(&$form_state, $rtype = NULL) { 
  $form = array();
  
  $form['name'] = array(
    '#type'           => 'textfield',
    '#title'          => t('Name'),
    '#maxlength'      => 255,
    '#default_value'  => $rtype->name,
    '#description'    => t("Example: buddy, friend, colleague."),
    '#required'       => TRUE,
  );  
  $form['oneway'] = array(
    '#type'           => 'checkbox',
    '#title'          => t('This is a oneway relationship'),
    '#default_value'  => $rtype->oneway,
    '#description'    => t('Check this if this relationship should only go one way (Example: Fan, Subscriber)'),
  );  
  $form['backrelation'] = array(
    '#type'           => 'checkbox',
    '#title'          => t('Free Backrealation'),
    '#default_value'  => $rtype->backrelation,
    '#description'    => t('...'),
  ); 
  $form['active'] = array(
    '#type'           => 'checkbox',
    '#title'          => t('Relationtype is active'),
    '#default_value'  => $rtype->active,
    '#description'    => t('If checked, users can use this relationship'),
  );
  $form['submit'] = array(
    '#type'           => 'submit',
    '#value'          => 'Save',
  );
  
  // extra for edit process
  if($rtype != NULL ) {
    $form['rtid'] = array(
      '#type'           => 'hidden',
      '#default_value'  => $rtype->rtid, 
    );    
  }
  
  return $form;
}

/**
 * Submit function for edit/delete a relationtype
 */
function buddylist_ui_admin_form_edit_submit($form, &$form_state) { 
  $res = new stdClass();
  foreach(array('name', 'oneway', 'backrelation', 'active', 'rtid') as $key) {
    $res->{$key} = $form_state['values'][$key];
  }
  
  if(is_numeric($res->rtid))
    drupal_set_message(t('Relation type has been updated'));
  else {
    drupal_set_message(t('Relation type has been saved'));
  }
  
  buddylist_api_rtype_save($res);
  
  $form_state['redirect'] = 'admin/buddylist/rtypes';
}


/**
 * Returns the form for deleting a rtype
 */
function buddylist_ui_admin_form_delete(&$form_state, $rtid = NULL) { 
  if ($rtid) {
    $form['rtid'] = array(
      '#type'   => 'value',
      '#value'  => (int)$rtid->rtid,
    );
    
    return confirm_form(
      $form,
      t('Are you sure you want to delete %name?', array('%name' => $rtid->name)),
      'admin/buddylist/rtypes',
      t('This action cannot be undone.'),
      t('Delete'), t('Cancel')
    );
  }
  else {
    drupal_set_message(t('This relationtype does not exist.'));
    drupal_goto('admin/buddylist/rtypes');
  }
}

/**
 * Submit function for deleting a relationtype
 */
function buddylist_ui_admin_form_delete_submit($form, &$form_state) {
  $rtype = buddylist_api_rtype_load($form_state['values']['rtid']);
  buddylist_api_rtype_delete($rtype);
  drupal_set_message(t('Relationship has been deleted.'));
  $form_state['redirect'] = 'admin/buddylist/rtypes';
}